Crate wasmsh_runtime

Crate wasmsh_runtime 

Shared shell runtime core for wasmsh.

Platform-agnostic execution engine: parse -> AST -> HIR -> runtime executor.

Most shell semantics are executed by interpreting HIR directly inside this crate. A bounded subset of top-level and/or lists is lowered through wasmsh-ir into wasmsh-vm, but that is an optimization and parity path rather than the primary executor for the whole grammar.

Structs

BrowserConfig
Configuration for the browser runtime.
ExternalCommandResult
Result from an external command handler.
ExternalCommandStdin
WorkerRuntime
The worker-side runtime that processes host commands.

Enums

ExecutionPoll

Functions

extglob_match
Match a name against an extglob pattern.

Type Aliases

ExternalCommandHandler
Callback type for external (host-provided) commands.